@@ -10,9 +10,8 @@ import sys
 
 class Rpdb(pdb.Pdb):
 
-    def __init__(self, port=4444):
+    def __init__(self, addr="127.0.0.1", port=4444):
         """Initialize the socket and initialize pdb."""
-        addr = socket.gethostname()
 
         # Writes to stdout are forbidden in mod_wsgi environments
         try:
@@ -58,6 +57,6 @@ def set_trace():
     debugger = Rpdb()
     try:
         debugger.set_trace(sys._getframe().f_back)
-    finally:
-        debugger.shutdown()
+    except Exception as e:
+        print e
 
